@@ -2,7 +2,7 @@ package Acme::MetaSyntactic::dilbert;
 use strict;
 use Acme::MetaSyntactic::List;
 our @ISA = qw( Acme::MetaSyntactic::List );
-our $VERSION = '1.002';
+our $VERSION = '1.003';
 __PACKAGE__->init();
 
 our %Remote = (
@@ -41,6 +41,12 @@ Sbastien Aperghis-Tramoni.
 
 =item *
 
+2013-06-03 - v1.003
+
+Updated from the source web site in Acme-MetaSyntactic-Themes version 1.032.
+
+=item *
+
 2013-01-14 - v1.002
 
 Updated from the source web site in Acme-MetaSyntactic-Themes version 1.029.
@@ -228,3 +234,4 @@ mutobu_the_impaler nancy neo old_johannsen oobanoobah pete raj rodney
 ronald rubbin_robin ruth sarah scott shelly silent_gary sue_boysenberry
 tom_jackson trixie victor vlad wolfgang
 jb_hopper
+stanky_bathurd
